@@ -86,7 +86,7 @@ class PaymentDataSplit(BaseModel):
 
 
 class PaymentData(BaseModel):
-    transaction_id: Union[UUID, None]
+    transaction_id: Union[str, None]
     paid_at: Union[str, None]
     expire_at: str
     amount: float
