@@ -91,7 +91,7 @@ def get_application_data(
     }
 
 
-def get_payment_data(**kwargs):
+def get_payment_event_data(**kwargs):
     return {
         'id': 'bb7044e4-066c-4bf7-915e-87ee97270eae',
         'user_id': '43f619df-3ba2-4d9d-bcdd-270484eac44d',
@@ -153,3 +153,100 @@ def get_payment_data(**kwargs):
         'app_id': 'payment-dispatcher:1.0.15',
         **kwargs,
     }
+
+
+def get_payment_data(**kwargs):
+    return {
+        'transaction_id': None,
+        'paid_at': None,
+        'expire_at': '2022-09-06T10:28:42+02:00',
+        'amount': 1,
+        'currency': 'EUR',
+        'notice_code': None,
+        'iud': 'bb7044e4066c4bf7915e87ee97270eae',
+        'iuv': None,
+        'split': [],
+        **kwargs,
+    }
+
+
+def get_split_data(**kwargs):
+    return {
+        'amount': 1,
+        'code': 'CODE',
+        'meta': {},
+        **kwargs,
+    }
+
+
+def get_payer_data(**kwargs):
+    return {
+        'type': 'human',
+        'tax_identification_number': 'SLVLNZ76P01G843V',
+        'name': 'Lorenzo',
+        'family_name': 'Salvadorini',
+        'street_name': None,
+        'building_number': None,
+        'postal_code': None,
+        'town_name': None,
+        'country_subdivision': None,
+        'country': 'IT',
+        'email': 'raffaele.luccisano@opencontent.it',
+        **kwargs,
+    }
+
+
+def get_links_data(**kwargs):
+    return {
+        'online_payment_begin': {'url': None, 'last_opened_at': None, 'method': 'GET'},
+        'online_payment_landing': {
+            'url': 'https://devsdc.opencontent.it/'
+            'comune-di-bugliano/it/pratiche/a51cc065-4fb1-4ace-8d3f-e3a70c867472/detail',
+            'last_opened_at': None,
+            'method': 'GET',
+        },
+        'offline_payment': {'url': None, 'last_opened_at': None, 'method': 'GET'},
+        'receipt': {'url': None, 'last_opened_at': None, 'method': 'GET'},
+        'notify': [
+            {
+                'url': 'https://devsdc.opencontent.it/'
+                'comune-di-bugliano/api/applications/a51cc065-4fb1-4ace-8d3f-e3a70c867472/payment',
+                'method': 'POST',
+                'sent_at': None,
+            },
+        ],
+        'update': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET'},
+        **kwargs,
+    }
+
+
+def get_online_payment_begin_data(**kwargs):
+    return {'url': None, 'last_opened_at': None, 'method': 'GET', **kwargs}
+
+
+def get_online_payment_landing_data(**kwargs):
+    return {
+        'url': 'https://devsdc.opencontent.it/'
+        'comune-di-bugliano/it/pratiche/a51cc065-4fb1-4ace-8d3f-e3a70c867472/detail',
+        'last_opened_at': None,
+        'method': 'GET',
+        **kwargs,
+    }
+
+
+def get_notify_data(**kwargs):
+    return {
+        'url': 'https://devsdc.opencontent.it/'
+        'comune-di-bugliano/api/applications/a51cc065-4fb1-4ace-8d3f-e3a70c867472/payment',
+        'method': 'POST',
+        'sent_at': None,
+        **kwargs,
+    }
+
+
+def get_offline_payment_data(**kwargs):
+    return {'url': None, 'last_opened_at': None, 'method': 'GET', **kwargs}
+
+
+def get_update_data(**kwargs):
+    return {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET', **kwargs}
