@@ -1,5 +1,5 @@
 import json
-from datetime import datetime, timezone
+from datetime import datetime, timedelta, timezone
 from unittest import TestCase
 
 from freezegun import freeze_time
@@ -85,12 +85,40 @@ class PaymentTestCase(TestCase):
             payment.update_time('links.update.last_check_at')
             self.assertEqual(payment.links.update.last_check_at, NOW)
 
-    def test_payment_update_check_time(self):
-        payment = Payment(**get_payment_event_data(crated_at=NOW))
+    def test_payment_update_check_time_missing_last_check_at(self):
+        payment = Payment(**get_payment_event_data(created_at=NOW.isoformat()))
         with freeze_time(NOW):
             payment.update_check_time()
             self.assertEqual(payment.links.update.last_check_at, None)
 
+    def test_payment_update_check_time(self):
+        payment = Payment(**get_payment_event_data(created_at=NOW.isoformat()))
+        with freeze_time(NOW):
+            payment.update_time('links.update.last_check_at')
+            payment.update_check_time()
+            self.assertEqual(payment.links.update.next_check_at, NOW + timedelta(minutes=1))
+        with freeze_time(NOW + timedelta(minutes=1)):
+            payment.update_time('links.update.last_check_at')
+            payment.update_check_time()
+            self.assertEqual(payment.links.update.next_check_at, NOW + timedelta(minutes=1 + 1))
+        with freeze_time(NOW + timedelta(minutes=15)):
+            payment.update_time('links.update.last_check_at')
+            payment.update_check_time()
+            self.assertEqual(payment.links.update.next_check_at, NOW + timedelta(minutes=15 + 5))
+        with freeze_time(NOW + timedelta(days=7)):
+            payment.update_time('links.update.last_check_at')
+            payment.update_check_time()
+            self.assertEqual(payment.links.update.next_check_at, NOW + timedelta(days=7, hours=1))
+        with freeze_time(NOW + timedelta(days=30)):
+            payment.update_time('links.update.last_check_at')
+            payment.update_check_time()
+            self.assertEqual(payment.links.update.next_check_at, NOW + timedelta(days=30, hours=6))
+        with freeze_time(NOW + timedelta(days=366)):
+            payment.update_time('links.update.last_check_at')
+            payment.update_check_time()
+            self.assertEqual(payment.links.update.next_check_at, None)
+            self.assertEqual(payment.status, PaymentStatus.STATUS_EXPIRED)
+
     def test_payer_country(self):
         with self.assertRaises(ValidationError):
             Payer(**get_payer_data(country='XX'))
